<?php

namespace Drupal\ui_suite_dsfr_ft\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a block with multiple menu rendered inside patterns.
 *
 * @Block(
 *   id = "ui_suite_dsfr_display_modal",
 *   admin_label = @Translation("UI Suite dsfr display modal"),
 *   category = @Translation("UI Suite DSFR"),
 * )
 */
class DisplayModalBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);
    $form['title'] = [
      '#type' => 'textfield',
      '#default_value' => $defaults['title'] ?? t('Display settings'),
      '#required' => TRUE,
      '#title' => t('Title of modal'),
    ];
    // Cannot use the checkboxes element cause the #states/required not working.
    $form['text'] = [
      '#type' => 'textarea',
      '#default_value' => $defaults['text'] ?? t('Choose a theme to personalize the appearance of site.'),
      '#required' => TRUE,
      '#title' => t('Body of modal'),
    ];
    $form['display_options'] = [
      '#type' => 'checkboxes',
      '#required' => TRUE,
      '#default_value' => $defaults['display_options'] ?? [
          'light',
          'dark',
          'system',
        ],
      '#options' => [
        'light' => t('Light'),
        'dark' => t('Dark'),
        'system' => t('System'),
      ],
      '#title' => t('Theme display option'),
      '#description' => t('Check the display options available.'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $this->configuration['title'] = $form_state->getValue('title');
    $this->configuration['text'] = $form_state->getValue('text');
    $this->configuration['display_options'] = $form_state->getValue('display_options');
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $modal_id = 'fr-theme-modal';
    // Add the modal to the content.
    $dsfr_theme_display = [
      'light' => [
        'title' => t('Light'),
        'attributes' => [
          'id' => 'light',
          'title' => t('Light Theme'),
          'svg' => 'environment/sun',
        ],
      ],
      'dark' => [
        'title' => t('Dark'),
        'attributes' => [
          'id' => 'dark',
          'title' => t('Dark Theme'),
          'svg' => 'environment/moon',
        ],
      ],
      'system' => [
        'title' => t('System'),
        'attributes' => [
          'id' => 'system',
          'title' => t('System Theme'),
          'svg' => 'system/system',
        ],
      ],
    ];
    foreach ($dsfr_theme_display as $theme_option => $theme_data) {
      if (empty($this->configuration['display_options'][$theme_option])) {
        unset($dsfr_theme_display[$theme_option]);
      }
    }
    $display_content = [
      '#type' => 'pattern',
      '#id' => 'display',
      '#fields' => [
        'title' => $this->configuration['text'] ?? t('Choose a theme to personalize the appearance of site.'),
      ],
      '#settings' => [
        'themes' => $dsfr_theme_display,
      ],
    ];
    return [
      'modal' => [
        '#type' => 'pattern',
        '#id' => 'modal',
        '#attached' => ['library' => 'ui_suite_dsfr_ft/dsfr-scheme'],
        '#fields' => [
          'title' => $this->configuration['title'] ?? t('Display settings'),
          'body' => $display_content,
        ],
        '#settings' => [
          'modal_id' => $modal_id,
        ],
      ],
    ];
  }

}

